@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 #--------------------------------------------------------------------------
 
@@ -86,15 +86,15 @@ sub search {
 	$self->found(0);
 	$self->book(undef);
 
-	my $mechanize = WWW::Mechanize->new();
-    $mechanize->agent_alias( 'Linux Mozilla' );
-	$mechanize->get( SEARCH . $isbn );
+	my $mech = WWW::Mechanize->new();
+    $mech->agent_alias( 'Linux Mozilla' );
 
+    eval { $mech->get( SEARCH . $isbn ) };
     return $self->handler("TheNile website appears to be unavailable.")
-	    unless($mechanize->success());
+	    unless($@ || $mech->success());
 
 	# The Book page
-    my $html = $mechanize->content();
+    my $html = $mech->content();
 
 	return $self->handler("Failed to find that book on TheNile website.")
 		if($html =~ m!We're sorry, but your search returned no results.!si);
@@ -136,7 +136,7 @@ sub search {
 		'isbn'			=> $data->{isbn13},
 		'author'		=> $data->{author},
 		'title'			=> $data->{title},
-		'book_link'		=> $mechanize->uri(),
+		'book_link'		=> $mech->uri(),
 		'image_link'	=> $data->{image},
 		'thumb_link'	=> $data->{thumb},
 		'description'	=> $data->{description},
@@ -173,6 +173,18 @@ L<WWW::Scraper::ISBN>,
 L<WWW::Scraper::ISBN::Record>,
 L<WWW::Scraper::ISBN::Driver>
 
+=head1 BUGS, PATCHES & FIXES
+
+There are no known bugs at the time of this release. However, if you spot a
+bug or are experiencing difficulties that are not explained within the POD
+documentation, please send an email to barbie@cpan.org or submit a bug to the
+RT system (http://rt.cpan.org/Public/Dist/Display.html?Name=WWW-Scraper-ISBN-TheNile_Driver).
+However, it would help greatly if you are able to pinpoint problems or even
+supply a patch.
+
+Fixes are dependant upon their severity and my availablity. Should a fix not
+be forthcoming, please feel free to (politely) remind me.
+
 =head1 AUTHOR
 
   Barbie, <barbie@cpan.org>
@@ -180,7 +192,7 @@ L<WWW::Scraper::ISBN::Driver>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2004-2010 Barbie for Miss Barbell Productions
+  Copyright (C) 2010 Barbie for Miss Barbell Productions
 
   This module is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
